@@ -316,11 +316,11 @@ class FargateToDynamoDBProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = ClusterProps(**cluster_props)
+            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = TableProps(**dynamo_table_props)
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(FargateToDynamoDBProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
